@@ -1,11 +1,16 @@
 package org.ovirt.engine.ui.webadmin.section.main.view.tab.network;
 
 import org.ovirt.engine.ui.common.idhandler.ElementIdHandler;
+import org.ovirt.engine.ui.common.presenter.NetworkBreadCrumbsPresenterWidget;
 import org.ovirt.engine.ui.common.widget.tab.AbstractTabPanel;
+import org.ovirt.engine.ui.common.widget.tab.DetailTabLayout;
+import org.ovirt.engine.ui.webadmin.section.main.presenter.tab.NetworkActionPanelPresenterWidget;
 import org.ovirt.engine.ui.webadmin.section.main.presenter.tab.network.NetworkSubTabPanelPresenter;
 import org.ovirt.engine.ui.webadmin.section.main.view.AbstractSubTabPanelView;
 import org.ovirt.engine.ui.webadmin.widget.tab.SimpleTabPanel;
+
 import com.google.gwt.core.client.GWT;
+import com.google.inject.Inject;
 
 public class NetworkSubTabPanelView extends AbstractSubTabPanelView implements NetworkSubTabPanelPresenter.ViewDef {
 
@@ -13,10 +18,15 @@ public class NetworkSubTabPanelView extends AbstractSubTabPanelView implements N
         ViewIdHandler idHandler = GWT.create(ViewIdHandler.class);
     }
 
-    private final SimpleTabPanel tabPanel = new SimpleTabPanel();
+    private final SimpleTabPanel tabPanel;
 
-    public NetworkSubTabPanelView() {
+    @Inject
+    public NetworkSubTabPanelView(NetworkBreadCrumbsPresenterWidget breadCrumbs,
+            NetworkActionPanelPresenterWidget actionPanel, DetailTabLayout detailTabLayout) {
+        tabPanel = new SimpleTabPanel(breadCrumbs, actionPanel, detailTabLayout);
         initWidget(getTabPanel());
+        actionPanel.removeButton(actionPanel.getNewButtonDefinition());
+        actionPanel.removeButton(actionPanel.getImportButtonDefinition());
     }
 
     @Override
